@@ -1,3 +1,5 @@
+use std::fmt::Display;
+
 use walkdir::DirEntry;
 
 use crate::filescanner::*;
@@ -15,6 +17,12 @@ impl FilenameScanner {
     }
 }
 
+impl Display for FilenameScanner {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        write!(f, "{}", "FilenameScanner")
+    }
+}
+
 impl FileScanner for FilenameScanner
 {
     fn scan_file(&self, file: &DirEntry) -> Vec<anyhow::Result<ScannerFinding>> {
